@@ -1,12 +1,12 @@
 package WebService::Toggl::API::ProjectUsers;
 
 use Moo;
-with 'WebService::Toggl::API', 'WebService::Toggl::Role::Set';
+with 'WebService::Toggl::Role::API', 'WebService::Toggl::Role::Set';
 use namespace::clean;
 
 sub list_of { '::ProjectUser' }
 
-sub my_url { '/project_users' }
+sub api_path { 'project_users' }
 
 
 1;
